@@ -2,6 +2,7 @@
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
 
+from __future__ import annotations
 
 INCLUDES = """
 #include <openssl/evp.h>
@@ -57,10 +58,6 @@ EVP_CIPHER_CTX *EVP_CIPHER_CTX_new(void);
 void EVP_CIPHER_CTX_free(EVP_CIPHER_CTX *);
 int EVP_CIPHER_CTX_set_key_length(EVP_CIPHER_CTX *, int);
 
-int EVP_MD_CTX_copy_ex(EVP_MD_CTX *, const EVP_MD_CTX *);
-int EVP_DigestInit_ex(EVP_MD_CTX *, const EVP_MD *, ENGINE *);
-int EVP_DigestUpdate(EVP_MD_CTX *, const void *, size_t);
-int EVP_DigestFinal_ex(EVP_MD_CTX *, unsigned char *, unsigned int *);
 int EVP_DigestFinalXOF(EVP_MD_CTX *, unsigned char *, size_t);
 const EVP_MD *EVP_get_digestbyname(const char *);
 
@@ -69,8 +66,6 @@ void EVP_PKEY_free(EVP_PKEY *);
 int EVP_PKEY_type(int);
 int EVP_PKEY_size(EVP_PKEY *);
 RSA *EVP_PKEY_get1_RSA(EVP_PKEY *);
-DSA *EVP_PKEY_get1_DSA(EVP_PKEY *);
-DH *EVP_PKEY_get1_DH(EVP_PKEY *);
 
 int EVP_PKEY_encrypt(EVP_PKEY_CTX *, unsigned char *, size_t *,
                      const unsigned char *, size_t);
@@ -86,17 +81,8 @@ int EVP_VerifyUpdate(EVP_MD_CTX *, const void *, size_t);
 int EVP_VerifyFinal(EVP_MD_CTX *, const unsigned char *, unsigned int,
                     EVP_PKEY *);
 
-int EVP_DigestSignInit(EVP_MD_CTX *, EVP_PKEY_CTX **, const EVP_MD *,
-                       ENGINE *, EVP_PKEY *);
-int EVP_DigestSignUpdate(EVP_MD_CTX *, const void *, size_t);
-int EVP_DigestSignFinal(EVP_MD_CTX *, unsigned char *, size_t *);
-int EVP_DigestVerifyInit(EVP_MD_CTX *, EVP_PKEY_CTX **, const EVP_MD *,
-                         ENGINE *, EVP_PKEY *);
-
-
 
 EVP_PKEY_CTX *EVP_PKEY_CTX_new(EVP_PKEY *, ENGINE *);
-EVP_PKEY_CTX *EVP_PKEY_CTX_new_id(int, ENGINE *);
 void EVP_PKEY_CTX_free(EVP_PKEY_CTX *);
 int EVP_PKEY_sign_init(EVP_PKEY_CTX *);
 int EVP_PKEY_sign(EVP_PKEY_CTX *, unsigned char *, size_t *,
@@ -116,8 +102,6 @@ int EVP_PKEY_set1_DH(EVP_PKEY *, DH *);
 
 int EVP_PKEY_cmp(const EVP_PKEY *, const EVP_PKEY *);
 
-int EVP_PKEY_keygen_init(EVP_PKEY_CTX *);
-int EVP_PKEY_keygen(EVP_PKEY_CTX *, EVP_PKEY **);
 int EVP_PKEY_derive_init(EVP_PKEY_CTX *);
 int EVP_PKEY_derive_set_peer(EVP_PKEY_CTX *, EVP_PKEY *);
 int EVP_PKEY_derive_set_peer_ex(EVP_PKEY_CTX *, EVP_PKEY *, int);
@@ -128,11 +112,6 @@ int EVP_PKEY_id(const EVP_PKEY *);
 EVP_MD_CTX *EVP_MD_CTX_new(void);
 void EVP_MD_CTX_free(EVP_MD_CTX *);
 
-int EVP_DigestSign(EVP_MD_CTX *, unsigned char *, size_t *,
-                   const unsigned char *, size_t);
-int EVP_DigestVerify(EVP_MD_CTX *, const unsigned char *, size_t,
-                     const unsigned char *, size_t);
-
 int EVP_PKEY_bits(const EVP_PKEY *);
 
 int EVP_PKEY_assign_RSA(EVP_PKEY *, RSA *);
@@ -142,15 +121,8 @@ int EVP_PKEY_set1_EC_KEY(EVP_PKEY *, EC_KEY *);
 
 int EVP_CIPHER_CTX_ctrl(EVP_CIPHER_CTX *, int, int, void *);
 
-int PKCS5_PBKDF2_HMAC(const char *, int, const unsigned char *, int, int,
-                      const EVP_MD *, int, unsigned char *);
-
 int EVP_PKEY_CTX_set_signature_md(EVP_PKEY_CTX *, const EVP_MD *);
 
-int EVP_PBE_scrypt(const char *, size_t, const unsigned char *, size_t,
-                   uint64_t, uint64_t, uint64_t, uint64_t, unsigned char *,
-                   size_t);
-
 EVP_PKEY *EVP_PKEY_new_raw_private_key(int, ENGINE *, const unsigned char *,
                                        size_t);
 EVP_PKEY *EVP_PKEY_new_raw_public_key(int, ENGINE *, const unsigned char *,
@@ -172,9 +144,6 @@ const long EVP_PKEY_DHX = -1;
 
 #if CRYPTOGRAPHY_IS_LIBRESSL || defined(OPENSSL_NO_SCRYPT)
 static const long Cryptography_HAS_SCRYPT = 0;
-int (*EVP_PBE_scrypt)(const char *, size_t, const unsigned char *, size_t,
-                      uint64_t, uint64_t, uint64_t, uint64_t, unsigned char *,
-                      size_t) = NULL;
 #else
 static const long Cryptography_HAS_SCRYPT = 1;
 #endif
