@@ -2,7 +2,7 @@
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
 
-import sys
+import contextlib
 
 import pytest
 
@@ -28,11 +28,6 @@ def pytest_report_header(config):
 def pytest_addoption(parser):
     parser.addoption("--wycheproof-root", default=None)
     parser.addoption("--enable-fips", default=False)
-    # REMOVE ME WHEN WE DROP PYTHON 3.6 SUPPORT
-    # This just adds a no-op flag so that we don't error on py36 where
-    # pytest-subtests is stuck on 0.8.0
-    if sys.version_info[:2] == (3, 6):
-        parser.addoption("--no-subtests-shortletter", action="store_true")
 
 
 def pytest_runtest_setup(item):
@@ -52,3 +47,21 @@ def backend(request):
     # Ensure the error stack is clear after the test
     errors = openssl_backend._consume_errors()
     assert not errors
+
+
+@pytest.fixture()
+def subtests():
+    # This is a miniature version of the pytest-subtests package, but
+    # optimized for lower overhead.
+    #
+    # When tests are skipped, these are not logged in the final pytest output.
+    yield SubTests()
+
+
+class SubTests:
+    @contextlib.contextmanager
+    def test(self):
+        try:
+            yield
+        except pytest.skip.Exception:
+            pass
